#ifndef GNUTELLA_H
#define GNUTELLA_H

//! Function code for PING messages.
#define CMD_PING     0x0
//! Function code for PONG messages.
#define CMD_PONG     0x1
//! Function code for BYE message.
#define CMD_BYE      0x2
//! Function code for QUERY messages.
#define CMD_QUERY    0x80
//! Function code for QUERY_HIT messages.
#define CMD_QUERYHIT 0x81
//! Function code for PUSH messages.
#define CMD_PUSH     0x40

#define HEADER_SIZE  23

#define IMAGES       "gif;bmp;jpg;jpeg;jpe;psp;xpm;tif;tiff;png;ps;eps;tga;xcf"
#define VIDEOS       "asf;mpg;mpeg;mov;qt;avi"
#define MUSIC        "wav;au;aif;aiff;ram;ra;mp3;ogg;rm"

#define CONNECT_STR  "GNUTELLA CONNECT/0.4\n\n"
#define RESPONSE_STR "GNUTELLA OK\n\n"

#define PING_SIZE      0
#define PONG_SIZE      14
#define PUSH_SIZE      26
#define QUERY_SIZE     3
#define QUERYHIT_SIZE  (27+11)

#endif
